searchNodes=[{"type":"module","title":"Envelope","doc":"A library for calculating envelopes of geometries and tools to compare them. This is most useful as an approximation of spacial relationships between more complicated geometries. iex&gt; Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) % Envelope { min_x : 2 , min_y : - 2 , max_x : 20 , max_y : 11 } iex&gt; Envelope . from_geo ( % Geo.LineString { coordinates : [ { 1 , 3 } , { 2 , - 1 } , { 0 , - 1 } , { 1 , 3 } ] } ) % Envelope { min_x : 0 , min_y : - 1 , max_x : 2 , max_y : 3 } You can also expand an existing Envelope with a geometry or another Envelope iex&gt; a = Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ...&gt; b = % Geo.LineString { coordinates : [ { 1 , 3 } , { 2 , - 1 } , { 0 , - 1 } , { 1 , 3 } ] } ...&gt; Envelope . expand ( a , b ) % Envelope { min_x : 0 , min_y : - 2 , max_x : 20 , max_y : 11 }","ref":"Envelope.html"},{"type":"function","title":"Envelope.area/1","doc":"Calculates the simple area of an Envelope. Examples iex&gt; Envelope . area ( Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ) 234","ref":"Envelope.html#area/1"},{"type":"function","title":"Envelope.area_gc/1","doc":"Estimates the area of an Envelope in square meters when the Envelope's coordinates are in degress of longitude and latitude. Examples iex&gt; Envelope . area_gc ( Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ) |&gt; round 2865575088701","ref":"Envelope.html#area_gc/1"},{"type":"function","title":"Envelope.center/1","doc":"Returns the center point of an envelope. Examples iex&gt; %Envelope{ min_x: 0, min_y: -1, max_x: 2, max_y: 5 } |&gt; Envelope.center() {1.0, 2.0} iex&gt; Envelope.empty() |&gt; Envelope.center() nil","ref":"Envelope.html#center/1"},{"type":"function","title":"Envelope.contains?/2","doc":"Returns whether one envelope fully contains another envelope or point. Examples iex&gt; Envelope . contains? ( ...&gt; % Envelope { min_x : - 1 , min_y : - 5 , max_x : 23 , max_y : 14 } , ...&gt; % Envelope { min_x : 0 , min_y : 3 , max_x : 7 , max_y : 4 } ) true iex&gt; Envelope . contains? ( ...&gt; % Envelope { min_x : - 1 , min_y : 5 , max_x : 23 , max_y : 14 } , ...&gt; % Envelope { min_x : - 2 , min_y : 5 , max_x : 7 , max_y : 4 } ) false iex&gt; Envelope . contains? ( ...&gt; % Geo.Polygon { coordinates : [ { - 1 , 3 } , { - 3 , - 1 } , { 5 , - 3 } , { 4 , 12 } , { - 2 , 11 } , { - 1 , 3 } ] } , ...&gt; { 0 , 11 } ) true","ref":"Envelope.html#contains?/2"},{"type":"function","title":"Envelope.empty/0","doc":"Returns an Envelope that represents no extent at all. This is primarily a convenience function for starting an expanding Envelope. Internally, &quot;empty&quot; Envelopes are represented with nil values for all extents. Note that there is a important distinction between an empty Envelope and an Envelope around a single Point (where the min and max for each axis are real numbers but may represent zero area). Examples iex&gt; Envelope . empty % Envelope { max_x : nil , max_y : nil , min_x : nil , min_y : nil } iex&gt; Envelope . empty |&gt; Envelope . empty? true","ref":"Envelope.html#empty/0"},{"type":"function","title":"Envelope.empty?/1","doc":"Returns true if the given envelope is empty (has non-existent extent), otherwise false Examples iex&gt; Envelope . empty |&gt; Envelope . empty? true iex&gt; % Envelope { min_x : 0 , min_y : - 1 , max_x : 2 , max_y : 3 } |&gt; Envelope . empty? false","ref":"Envelope.html#empty?/1"},{"type":"function","title":"Envelope.expand/2","doc":"Returns a new Envelope that is expanded to include an additional geometry. Examples iex&gt; a = Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ...&gt; b = % Geo.LineString { coordinates : [ { 1 , 3 } , { 2 , - 1 } , { 0 , - 1 } , { 1 , 3 } ] } ...&gt; Envelope . expand ( a , b ) % Envelope { min_x : 0 , min_y : - 2 , max_x : 20 , max_y : 11 } iex&gt; a = % Envelope { min_x : 0 , min_y : - 2 , max_x : 20 , max_y : 11 } ...&gt; b = % Envelope { min_x : 2 , min_y : - 3 , max_x : 12 , max_y : - 2 } ...&gt; Envelope . expand ( a , b ) % Envelope { min_x : 0 , min_y : - 3 , max_x : 20 , max_y : 11 } iex&gt; Envelope . empty ...&gt; |&gt; Envelope . expand ( % Envelope { min_x : 0 , min_y : - 2 , max_x : 12 , max_y : 11 } ) ...&gt; |&gt; Envelope . expand ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ...&gt; |&gt; Envelope . expand ( %{ type : &quot;Point&quot; , coordinates : { - 1 , 3 } } ) % Envelope { min_x : - 1 , min_y : - 2 , max_x : 20 , max_y : 11 } iex&gt; Envelope . expand ( Envelope . empty , Envelope . empty ) |&gt; Envelope . empty? true","ref":"Envelope.html#expand/2"},{"type":"function","title":"Envelope.expand_by/2","doc":"Returns a new Envelope that is expanded in positive and negative directions in each axis by radius . Examples iex&gt; Envelope . expand_by ( Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) , 3 ) % Envelope { min_x : - 1 , min_y : - 5 , max_x : 23 , max_y : 14 } iex&gt; Envelope . expand_by ( Envelope . empty , 4 ) |&gt; Envelope . empty? true","ref":"Envelope.html#expand_by/2"},{"type":"function","title":"Envelope.from_geo/1","doc":"Returns an Envelope that represents the extent of the geometry or coordinates. Examples iex&gt; Envelope . from_geo %{ coordinates : [ { 11 , 10 } , { 4 , 2.5 } , { 16 , 2.5 } , { 11 , 10 } ] } % Envelope { max_x : 16 , max_y : 10 , min_x : 4 , min_y : 2.5 } iex&gt; Envelope . from_geo [ { 11 , 10 } , { 4 , 2.5 } , { 16 , 2.5 } , { 11 , 10 } ] % Envelope { max_x : 16 , max_y : 10 , min_x : 4 , min_y : 2.5 } iex&gt; Envelope . from_geo % Geo.Polygon { coordinates : [ [ { 1 , 3 } , { 2 , - 1 } , { 0 , - 1 } , { 1 , 3 } ] ] } % Envelope { min_x : 0 , min_y : - 1 , max_x : 2 , max_y : 3 } iex&gt; Envelope . from_geo { 1 , 3 } % Envelope { min_x : 1 , min_y : 3 , max_x : 1 , max_y : 3 }","ref":"Envelope.html#from_geo/1"},{"type":"function","title":"Envelope.height/1","doc":"Simple distance from the bottom bounadary to the top boundary of the Envelope. Examples iex&gt; Envelope . height ( Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ) 13","ref":"Envelope.html#height/1"},{"type":"function","title":"Envelope.height_gc/1","doc":"When an Envelope's coordinates are in degress of longitude and latitude, calculates the great circle distance between the center of the north and south extent in meters. Examples iex&gt; Envelope . height_gc ( Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ) |&gt; round 1445536","ref":"Envelope.html#height_gc/1"},{"type":"function","title":"Envelope.intersects?/2","doc":"Returns whether two envelopes touch or intersect. Examples iex&gt; Envelope . intersects? ( ...&gt; % Envelope { min_x : - 1 , min_y : - 5 , max_x : 23 , max_y : 14 } , ...&gt; % Envelope { min_x : 0 , min_y : 3 , max_x : 7 , max_y : 4 } ) true iex&gt; Envelope . intersects? ( ...&gt; % Envelope { min_x : - 1 , min_y : 5 , max_x : 23 , max_y : 14 } , ...&gt; % Envelope { min_x : 0 , min_y : - 3 , max_x : 7 , max_y : 4 } ) false","ref":"Envelope.html#intersects?/2"},{"type":"function","title":"Envelope.to_geo/1","doc":"Returns a Geo.Polygon , Geo.LineString , or Geo.Point that is equal to the area covered by the given Envelope . Note that they exact type of the Geometry returned will depend on the nature of the Envelope: Geo.Point will be returned when an envelope has zero area and all extents are equal. Geo.LineString will be returned when an envelope has zero area and it extends along only one axes. Geo.Polygon will be returned when an envelope has non-zeron area Examples iex&gt; Envelope . to_geo % Envelope { max_x : 16 , max_y : 10 , min_x : 4 , min_y : 2.5 } % Geo.Polygon { coordinates : [ [ { 4 , 2.5 } , { 16 , 2.5 } , { 16 , 10 } , { 4 , 10 } , { 4 , 2.5 } ] ] } iex&gt; Envelope . to_geo % Envelope { min_x : 1 , min_y : 3 , max_x : 1 , max_y : 5 } % Geo.LineString { coordinates : [ { 1 , 3 } , { 1 , 5 } ] } iex&gt; Envelope . to_geo % Envelope { min_x : 1 , min_y : 3 , max_x : 4 , max_y : 3 } % Geo.LineString { coordinates : [ { 1 , 3 } , { 4 , 3 } ] } iex&gt; Envelope . to_geo % Envelope { min_x : 1 , min_y : 3 , max_x : 1 , max_y : 3 } % Geo.Point { coordinates : { 1 , 3 } }","ref":"Envelope.html#to_geo/1"},{"type":"function","title":"Envelope.width/1","doc":"Simple distance from the left bounadary to the right boundary of the Envelope. Examples iex&gt; Envelope . width ( Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ) 18","ref":"Envelope.html#width/1"},{"type":"function","title":"Envelope.width_gc/1","doc":"When an Envelope's coordinates are in degress of longitude and latitude, calculates the great circle distance between the center of the east and west extent in meters. Examples iex&gt; Envelope . width_gc ( Envelope . from_geo ( % Geo.Polygon { coordinates : [ [ { 2 , - 2 } , { 20 , - 2 } , { 11 , 11 } , { 2 , - 2 } ] ] } ) ) |&gt; round 1982362","ref":"Envelope.html#width_gc/1"},{"type":"function","title":"Envelope.within?/2","doc":"The inverse of the relationship tested by Envelope#contains? Examples iex&gt; Envelope . within? ( ...&gt; % Envelope { min_x : 0 , min_y : 3 , max_x : 7 , max_y : 4 } , ...&gt; % Envelope { min_x : - 1 , min_y : - 5 , max_x : 23 , max_y : 14 } ) true iex&gt; Envelope . within? ( ...&gt; % Geo.Polygon { coordinates : [ { - 1 , 3 } , { - 3 , - 1 } , { 5 , - 3 } , { 4 , 12 } , { - 2 , 11 } , { - 1 , 3 } ] } , ...&gt; { 0 , 11 } ) false","ref":"Envelope.html#within?/2"},{"type":"type","title":"Envelope.point/0","doc":"","ref":"Envelope.html#t:point/0"},{"type":"type","title":"Envelope.points/0","doc":"","ref":"Envelope.html#t:points/0"},{"type":"type","title":"Envelope.t/0","doc":"","ref":"Envelope.html#t:t/0"}]